@@ -33,15 +33,9 @@ else
 		continue
 	fi
 fi
-
-# Creat /dev/cdrom if needed (symlink does not exist on LiveCD). Chmod hack
-# for Asunder and burnbox allowing all users to burn/rip CD/DVD.
-#
-DRIVE_NAME=`cat /proc/sys/dev/cdrom/info | grep "drive name" | cut -f 3`
-if [ ! "`readlink /dev/cdrom`" ]; then
-	echo -n "Creating symlink : /dev/cdrom..."
-	ln -s /dev/$DRIVE_NAME /dev/cdrom
-	chmod 0666 /dev/cdrom
+# Restore sound config for installed system.
+if [ -f /var/lib/sound-card-driver ]; then
+	echo -n "Restoring last alsa configuration..."
+	alsactl restore
 	status
 fi
-chmod 0666 /dev/$DRIVE_NAME
